summaryrefslogtreecommitdiffstats
path: root/src/modules/torrent/libkvitorrent.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/modules/torrent/libkvitorrent.cpp')
-rw-r--r--src/modules/torrent/libkvitorrent.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/modules/torrent/libkvitorrent.cpp b/src/modules/torrent/libkvitorrent.cpp
index 9a929483..8ab218ab 100644
--- a/src/modules/torrent/libkvitorrent.cpp
+++ b/src/modules/torrent/libkvitorrent.cpp
@@ -86,9 +86,9 @@ static KviTorrentInterface *auto_detect_torrent_client(KviWindow * pOut = 0)
}
if(pOut)
{
- QString szOut;
- QString szNam = d->name();
- KviQString::sprintf(szOut,__tr2qs_ctx("Trying media player interface \"%Q\": score %d","mediaplayer"),&(szNam),iScore);
+ TQString szOut;
+ TQString szNam = d->name();
+ KviTQString::sprintf(szOut,__tr2qs_ctx("Trying media player interface \"%Q\": score %d","mediaplayer"),&(szNam),iScore);
pOut->output(KVI_OUT_MULTIMEDIA,szOut);
}
}
@@ -127,7 +127,7 @@ static KviTorrentInterface *auto_detect_torrent_client(KviWindow * pOut = 0)
if (!c->hasSwitch('q',"quiet")) \
{ \
c->warning(__tr2qs_ctx("The selected torrent client interface failed to execute the requested function", "torrent")); \
- QString tmp = __tr2qs_ctx("Last interface error: ", "torrent"); \
+ TQString tmp = __tr2qs_ctx("Last interface error: ", "torrent"); \
tmp += KviTorrentInterface::selected()->lastError(); \
c->warning(tmp); \
} \
@@ -169,7 +169,7 @@ static KviTorrentInterface *auto_detect_torrent_client(KviWindow * pOut = 0)
{ \
kvs_int_t arg1; \
kvs_int_t arg2; \
- QString arg3; \
+ TQString arg3; \
KVSM_PARAMETERS_BEGIN(c) \
KVSM_PARAMETER(__argname1, KVS_PT_INT, 0, arg1) \
KVSM_PARAMETER(__argname2, KVS_PT_INT, 0, arg2) \
@@ -191,7 +191,7 @@ static KviTorrentInterface *auto_detect_torrent_client(KviWindow * pOut = 0)
TC_KVS_FUNCTION(__name) \
{ \
TC_KVS_FAIL_ON_NO_INTERFACE \
- QString szRet = KviTorrentInterface::selected()->__ifacecommand(); \
+ TQString szRet = KviTorrentInterface::selected()->__ifacecommand(); \
c->returnValue()->setString(szRet); \
return true; \
}
@@ -235,7 +235,7 @@ static KviTorrentInterface *auto_detect_torrent_client(KviWindow * pOut = 0)
KVSM_PARAMETER(__argname, KVS_PT_INT, 0, arg) \
KVSM_PARAMETERS_END(c) \
TC_KVS_FAIL_ON_NO_INTERFACE \
- QString szRet = KviTorrentInterface::selected()->__ifacecommand(arg); \
+ TQString szRet = KviTorrentInterface::selected()->__ifacecommand(arg); \
c->returnValue()->setString(szRet); \
return true; \
}
@@ -250,7 +250,7 @@ static KviTorrentInterface *auto_detect_torrent_client(KviWindow * pOut = 0)
KVSM_PARAMETER(__argname2, KVS_PT_INT, 0, arg2) \
KVSM_PARAMETERS_END(c) \
TC_KVS_FAIL_ON_NO_INTERFACE \
- QString szRet = KviTorrentInterface::selected()->__ifacecommand(arg1, arg2); \
+ TQString szRet = KviTorrentInterface::selected()->__ifacecommand(arg1, arg2); \
c->returnValue()->setString(szRet); \
return true; \
}
@@ -694,7 +694,7 @@ TC_KVS_SIMPLE_COMMAND(stopAll, stopAll)
TC_KVS_COMMAND(setClient)
{
- QString client;
+ TQString client;
KVSM_PARAMETERS_BEGIN(c)
KVSM_PARAMETER("client", KVS_PT_STRING, 0, client)
@@ -873,8 +873,8 @@ static bool torrent_module_ctrl(KviModule * m,const char * operation,void * para
debug("torrent module ctrl");
/* if(kvi_strEqualCI(operation,"getAvailableMediaPlayers"))
{
- // we expect param to be a pointer to QStringList
- QStringList * l = (QStringList *)param;
+ // we expect param to be a pointer to TQStringList
+ TQStringList * l = (TQStringList *)param;
for(KviMediaPlayerInterfaceDescriptor * d = g_pDescriptorList->first();d;d = g_pDescriptorList->next())
{
l->append(d->name());